==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTTryNode.h <==
// public class soot.dava.internal.AST.ASTTryNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 322331231f4c8291 soot_dava_internal_AST_ASTTryNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTTryNode_H_
#define _JC_soot_dava_internal_AST_ASTTryNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$sub_refs	_jc_soot_dava_internal_AST_ASTTryNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$refs	_jc_soot_dava_internal_AST_ASTTryNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$nonrefs	_jc_soot_dava_internal_AST_ASTTryNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$object	_jc_soot_dava_internal_AST_ASTTryNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vmethods	_jc_soot_dava_internal_AST_ASTTryNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vtable	_jc_soot_dava_internal_AST_ASTTryNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vtype	_jc_soot_dava_internal_AST_ASTTryNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$_init$ae5efd40edac42f6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTTryNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fCatchList$cc344496159c4e65(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fExceptionMap$91520fb7e60fa36b(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fExceptionSet$6e51c33fef09369d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fTryBody$139fb1803da8186d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fTryBodyContainer$3c6d957d267aa615(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern jboolean _jc_soot_dava_internal_AST_ASTTryNode$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$perform__5fAnalysisOnSubBodies$69da530fdb259b86(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTTryNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fCatchList$cc344496159c4e65;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fExceptionMap$91520fb7e60fa36b;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fExceptionSet$6e51c33fef09369d;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fTryBody$139fb1803da8186d;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fTryBodyContainer$3c6d957d267aa615;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$perform__5fAnalysisOnSubBodies$69da530fdb259b86;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTTryNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	struct _jc_object	*(*get__5fCatchList$cc344496159c4e65)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	struct _jc_object	*(*get__5fExceptionMap$91520fb7e60fa36b)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	struct _jc_object	*(*get__5fExceptionSet$6e51c33fef09369d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	struct _jc_object	*(*get__5fTryBody$139fb1803da8186d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	*(*get__5fTryBodyContainer$3c6d957d267aa615)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	void	(*perform__5fAnalysisOnSubBodies$69da530fdb259b86)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTTryNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTTryNode$vmethods	soot_dava_internal_AST_ASTTryNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTTryNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTTryNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode$sub_refs {
	struct _jc_object	*tryBody;
	struct _jc_object	*catchList;
	struct _jc_object	*exceptionMap;
	struct _jc_object	*paramMap;
	struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	*tryBodyContainer;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode$refs {
    _jc_soot_dava_internal_AST_ASTTryNode$sub_refs	soot_dava_internal_AST_ASTTryNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs	soot_dava_internal_AST_ASTTryNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTTryNode$object {
	_jc_soot_dava_internal_AST_ASTTryNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTTryNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTTryNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTTryNode$vtype _jc_soot_dava_internal_AST_ASTTryNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTTryNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTTryNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTTryNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTTryNode.h <==
// public class soot.dava.internal.AST.ASTTryNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 322331231f4c8291 soot_dava_internal_AST_ASTTryNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTTryNode_H_
#define _JC_soot_dava_internal_AST_ASTTryNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Map$object;
struct _jc_java_util_Set$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$sub_refs	_jc_soot_dava_internal_AST_ASTTryNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$refs	_jc_soot_dava_internal_AST_ASTTryNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$nonrefs	_jc_soot_dava_internal_AST_ASTTryNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTTryNode$object	_jc_soot_dava_internal_AST_ASTTryNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vmethods	_jc_soot_dava_internal_AST_ASTTryNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vtable	_jc_soot_dava_internal_AST_ASTTryNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTTryNode$vtype	_jc_soot_dava_internal_AST_ASTTryNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$_init$ae5efd40edac42f6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTTryNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fCatchList$cc344496159c4e65(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fExceptionMap$91520fb7e60fa36b(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fExceptionSet$6e51c33fef09369d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fTryBody$139fb1803da8186d(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object *_jc_soot_dava_internal_AST_ASTTryNode$method$get__5fTryBodyContainer$3c6d957d267aa615(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_dava_internal_AST_ASTTryNode$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$perform__5fAnalysisOnSubBodies$69da530fdb259b86(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTTryNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTTryNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fCatchList$cc344496159c4e65;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fExceptionMap$91520fb7e60fa36b;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fExceptionSet$6e51c33fef09369d;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fTryBody$139fb1803da8186d;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$get__5fTryBodyContainer$3c6d957d267aa615;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$perform__5fAnalysisOnSubBodies$69da530fdb259b86;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTTryNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTTryNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get__5fCatchList$cc344496159c4e65)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get__5fExceptionMap$91520fb7e60fa36b)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get__5fExceptionSet$6e51c33fef09369d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*get__5fTryBody$139fb1803da8186d)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	*(*get__5fTryBodyContainer$3c6d957d267aa615)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysisOnSubBodies$69da530fdb259b86)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTTryNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTTryNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTTryNode$vmethods	soot_dava_internal_AST_ASTTryNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTTryNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTTryNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode$sub_refs {
	struct _jc_object	*tryBody;
	struct _jc_object	*catchList;
	struct _jc_object	*exceptionMap;
	struct _jc_object	*paramMap;
	struct _jc_soot_dava_internal_AST_ASTTryNode__24container$object	*tryBodyContainer;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode$refs {
    _jc_soot_dava_internal_AST_ASTTryNode$sub_refs	soot_dava_internal_AST_ASTTryNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTTryNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTTryNode$sub_nonrefs	soot_dava_internal_AST_ASTTryNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTTryNode$object {
	_jc_soot_dava_internal_AST_ASTTryNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTTryNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTTryNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTTryNode$vtype _jc_soot_dava_internal_AST_ASTTryNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTTryNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTTryNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTTryNode_H_ */
